pub struct AttributesQuery<'a> {
pub apply_filters: Option<&'a str>,
pub attribute_group: Vec<String>,
pub entity_type: Option<&'a str>,
pub expand: Vec<String>,
pub minmax: Vec<String>,
pub only_filterable: Option<bool>,
pub only_returnable: Option<bool>,
pub only_sortable: Option<bool>,
}Expand description
Optional query parameters for Client::get_attributes.
Every field is documented as optional. Build via
AttributesQuery::default() and field-by-field assignment.
Fields
apply_filters: Option<&'a str>Specifies which filters to apply to the search.
attribute_group: Vec<String>Returns only attributes belonging to the specified attribute groups
(free string per the doc — must be one of the documented enum
values, e.g. EXCHANGE_INFO, PRICE_INFO).
entity_type: Option<&'a str>Returns only attributes belonging to the specified entity type
(free string per the doc — must be one of the documented enum
values, e.g. STOCKLIST, OPTIONLIST).
expand: Vec<String>Expand attribute values only for the listed attributes. The default
expand value is all.
minmax: Vec<String>Returns minimum and maximum values for the specified attributes.
only_filterable: Option<bool>Returns only filterable attributes.
only_returnable: Option<bool>Returns only returnable attributes.
only_sortable: Option<bool>Returns only sortable attributes.